==> lxqt-notificationd-2.2.0.tar.xz: lxqt-notificationd-2.2.0/config/translations/lxqt-config-notificationd_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Use the top of the notification as shown.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these notifications:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Duration</source>
        <translation>Doba trvání zobrazení</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="79"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Některá oznámení si nastavují svojí vlastní dobu trvání zobrazení.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="91"/>
        <source>Default duration:</source>
        <translation>Výchozí doba trvání:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="98"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="126"/>
        <source>Screen</source>
        <translation>Obrazovka</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="132"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Pokud není zaškrtnuto, oznámení se zobrazí vždy na hlavní obrazovce</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Ukázat oznámení na té obrazovce, na které se nachází ukazatel myši</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="145"/>
        <source>Do Not Disturb</source>
        <translation>Nerušení pozornosti</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="151"/>
        <source>Only save notifications</source>
        <translation>Upozornění nevyskakovat, jen ukládat</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Nespatřená oznámení</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Kolik nejnovějších držet uložených:</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Rozměry</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Rozestupy:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>Pozice na obrazovce</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Varování:&lt;/b&gt; Proces služby oznamování odpovídá pomalu.
Pokračuje se v pokusech o připojení se…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Varování:&lt;/b&gt; Není spuštěný žádný proces služby oznamování.
Použije se náhrada.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Varování:&lt;/b&gt; Je spuštěná jiná služba oznamování (od třetí strany) (%1).
Tato nastavení na ni nemají žádný vliv!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>vlevo nahoře</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>nahoře uprostřed</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>vpravo nahoře</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>vlevo uprostřed</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>vpravo uprostřed</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>vlevo dole</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>dole uprostřed</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>vpravo dole</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>Zkušební oznámení </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Toto je zkušební oznámení.
Všechna oznámení, procházející přes LXQt, se nyní budou objevovat zde.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Oznámení na ploše</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_2.3.0.orig.tar.xz: lxqt-notificationd-2.3.0/config/translations/lxqt-config-notificationd_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="85"/>
        <location filename="../advancedsettings.ui" line="95"/>
        <source>Use the top of the notification as shown.</source>
        <translation>Použít vršek upozornění, jak zobrazeno.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="88"/>
        <source>Ignore these notifications:</source>
        <translation>Ignorovat tato upozornění:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Duration</source>
        <translation>Doba trvání zobrazení</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="29"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Některá oznámení si nastavují svojí vlastní dobu trvání zobrazení.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="41"/>
        <source>Default duration:</source>
        <translation>Výchozí doba trvání:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="48"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="129"/>
        <source>Screen</source>
        <translation>Obrazovka</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Pokud není zaškrtnuto, oznámení se zobrazí vždy na hlavní obrazovce</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="138"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Ukázat oznámení na té obrazovce, na které se nachází ukazatel myši</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="113"/>
        <source>Do Not Disturb</source>
        <translation>Nerušení pozornosti</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="119"/>
        <source>Only save notifications</source>
        <translation>Upozornění nevyskakovat, jen ukládat</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="63"/>
        <source>Unattended Notifications</source>
        <translation>Nespatřená oznámení</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="71"/>
        <source>How many to save:</source>
        <translation>Kolik nejnovějších držet uložených:</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Rozměry</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Rozestupy:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>Poloha na obrazovce</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Varování:&lt;/b&gt; Proces služby oznamování odpovídá pomalu.
Pokračuje se v pokusech o připojení se…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Varování:&lt;/b&gt; Není spuštěný žádný proces služby oznamování.
Bude použita náhrada.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Varování:&lt;/b&gt; Je spuštěná jiná služba oznamování (od třetí strany) (%1).
Tato nastavení na ni nemají žádný vliv!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>vlevo nahoře</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>nahoře uprostřed</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>vpravo nahoře</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>vlevo uprostřed</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>vpravo uprostřed</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>vlevo dole</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>dole uprostřed</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>vpravo dole</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>Zkušební oznámení </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Toto je zkušební oznámení.
Všechna oznámení, procházející přes LXQt, se nyní budou objevovat zde.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Oznámení na ploše</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
</context>
</TS>
